@@ -13,6 +13,7 @@ from damask_parse import (
     write_load_case,
     write_geom,
     write_material_config,
+    write_numerics_config,
 )
 from damask import DADF5
 from damask_parse.utils import (
@@ -145,6 +146,11 @@ def write_damask_material(path, homogenization_schemes, homogenization_labels,
     )
 
 
+@input_mapper('numerics.config', 'simulate_volume_element_loading', 'CP_FFT')
+def write_damask_numerics(path, numerics):
+    write_numerics_config(Path(path).parent, numerics)
+
+
 @output_mapper('volume_element_response', 'simulate_volume_element_loading', 'CP_FFT')
 def read_damask_hdf5_file(hdf5_path, incremental_data, operations=None):
     return read_HDF5_file(hdf5_path, incremental_data, operations=operations)
